import { addTemplate, installModule, useNuxt, createResolver, defineNuxtModule, addPlugin, addComponentsDir, addImportsDir } from '@nuxt/kit';
import { createRequire } from 'node:module';
import { join } from 'pathe';
import { defu } from 'defu';



// -- Unbuild CommonJS Shims --
import __cjs_url__ from 'url';
import __cjs_path__ from 'path';
import __cjs_mod__ from 'module';
const __filename = __cjs_url__.fileURLToPath(import.meta.url);
const __dirname = __cjs_path__.dirname(__filename);
const require = __cjs_mod__.createRequire(import.meta.url);
const name = "manolis-ui";
const version = "1.1.4";

function installTailwind(moduleOptions, nuxt = useNuxt(), resolve = createResolver(import.meta.url).resolve) {
  const runtimeDir = resolve("./runtime");
  nuxt.hook("tailwindcss:config", function(tailwindConfig) {
    tailwindConfig.theme = tailwindConfig.theme || {};
    tailwindConfig.theme.extend = tailwindConfig.theme.extend || {};
    tailwindConfig.theme.extend.colors = tailwindConfig.theme.extend.colors || {};
    nuxt.options.appConfig.ui = {
      primary: "green",
      gray: "cool",
      strategy: "merge"
    };
  });
  const configTemplate = addTemplate({
    filename: "nuxtui-tailwind.config.cjs",
    write: true,
    getContents: ({ nuxt: nuxt2 }) => `
      const { defaultExtractor: createDefaultExtractor } = require('tailwindcss/lib/lib/defaultExtractor.js')

      const defaultExtractor = createDefaultExtractor({ tailwindConfig: { separator: ':' } })

      module.exports = {
        plugins: [
          require('daisyui')
        ],
        content: {
          files: [
            ${JSON.stringify(resolve(runtimeDir, "components/**/*.{vue,mjs,ts}"))},
            ${JSON.stringify(resolve(runtimeDir, "ui.config/**/*.{mjs,js,ts}"))}
          ],
          transform: {
            vue: (content) => {
              return content.replaceAll(/(?:\\r\\n|\\r|\\n)/g, ' ')
            }
          },
          extract: {
            vue: (content) => {
              return defaultExtractor(content)
            }
          }
        },
        daisyui: {
          themes: ["light", "dark"],
        },
      }
    `
  });
  const { configPath: userTwConfigPath = [], ...twModuleConfig } = nuxt.options.tailwindcss ?? {};
  const twConfigPaths = [
    configTemplate.dst,
    join(nuxt.options.rootDir, "tailwind.config")
  ];
  if (typeof userTwConfigPath === "string") {
    twConfigPaths.push(userTwConfigPath);
  } else {
    twConfigPaths.push(...userTwConfigPath);
  }
  return installModule("@nuxtjs/tailwindcss", defu({
    exposeConfig: true,
    config: {
      darkMode: "class"
    },
    configPath: twConfigPaths
  }, twModuleConfig));
}

createRequire(import.meta.url);
const module = defineNuxtModule({
  meta: {
    name,
    version,
    configKey: "manolisUI",
    compatibility: {
      nuxt: ">=3.10.0"
    }
  },
  defaults: {
    prefix: "",
    disableGlobalStyles: false
  },
  async setup(options, nuxt) {
    const { resolve } = createResolver(import.meta.url);
    const runtimeDir = resolve("./runtime");
    nuxt.options.build.transpile.push(runtimeDir);
    nuxt.options.build.transpile.push("nuxt-lucide-icons");
    await installTailwind(options, nuxt, resolve);
    if (!options.disableGlobalStyles) {
      nuxt.options.css.push(resolve(runtimeDir, "ui.css"));
    }
    addPlugin(resolve("./runtime/plugin"));
    const componentDirs = [
      "actions",
      "data-display",
      "data-input",
      "feedback",
      "layout",
      "navigation"
    ];
    for (const dir of componentDirs) {
      addComponentsDir({
        path: resolve(runtimeDir, "components", dir),
        prefix: options.prefix,
        global: options.global
      });
    }
    addImportsDir(resolve(runtimeDir, "composables"));
  }
});

export { module as default };
